@@ -6,25 +6,15 @@
  * Date        : 2010-12-15
  * Description : a Brightness/Contrast/Gamma settings container.
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2005-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BCG_CONTAINER_H
-#define DIGIKAM_BCG_CONTAINER_H
+#pragma once
 
 // Qt includes
 
@@ -33,6 +23,7 @@
 // Local includes
 
 #include "digikam_export.h"
+#include "digikam_globals.h"
 
 namespace Digikam
 {
@@ -44,7 +35,7 @@ class DIGIKAM_EXPORT BCGContainer
 
 public:
 
-    explicit BCGContainer();
+    BCGContainer() = default;
 
     bool isDefault()                                                                  const;
     bool operator==(const BCGContainer& other)                                        const;
@@ -56,13 +47,11 @@ public:
 
 public:
 
-    int    channel;
+    int    channel    = LuminosityChannel;
 
-    double brightness;
-    double contrast;
-    double gamma;
+    double brightness = 0.0;
+    double contrast   = 0.0;
+    double gamma      = 1.0;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_BCG_CONTAINER_H
