@@ -6,23 +6,13 @@
  * Date        : 2009-05-26
  * Description : History view.
  *
- * Copyright (C) 2009-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DHISTORY_VIEW_H
-#define DIGIKAM_DHISTORY_VIEW_H
+#pragma once
 
 // Qt includes
 
@@ -57,7 +47,7 @@ public:
 public:
 
     explicit DHistoryView(QWidget* const parent);
-    ~DHistoryView()                     override;
+    ~DHistoryView()                     override = default;
 
     void addEntry(const QString& msg,
                   EntryType type,
@@ -79,5 +69,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DHISTORY_VIEW_H
