@@ -112,9 +112,9 @@
 
 #define LIBEXEC_INSTALL_DIR "/usr/libexec"
 
-#define CMAKE_VERSION_STRING        "4.1.2-dirty"
+#define CMAKE_VERSION_STRING        "4.2.1"
 #define CMAKE_CXX_COMPILER_ID       "GNU"
 #define CMAKE_CXX_COMPILER_VERSION  "15.2.1"
-#define CMAKE_HOST_PRETTY_NAME      "Artix Linux"
+#define CMAKE_HOST_PRETTY_NAME      "Arch Linux"
 #define CMAKE_SYSTEM_PROCESSOR      "x86_64"
 #define CMAKE_HOST_SYSTEM_PROCESSOR "x86_64"
